@@ -20,7 +20,11 @@ extern int prefsOverrideRecipients;
 extern int prefsVerboseOutput;
 extern int prefsExtraCRLFAtEnd;
 extern int prefsAddComment;
+extern int prefsCacheDecrypted;
+extern int prefsCacheKeyrings;
+extern int addDashR;
 extern char prefsMyPager[MAX_COMMAND_LINE_LENGTH];
+extern char DecryptCacheName[MAX_COMMAND_LINE_LENGTH];
 
 #ifdef USE_DISPLAY_NAME
 	extern char mySecretKey[EMAIL_ADDRESS_MAX_LENGTH];
