@@ -1,13 +1,11 @@
-/* pgp4pine globals.c
+/* pgp4pine globals.c - global variables
  *
  * See common.c for the version and license.
  * Copyright (C) 1998 by Chris Wiegand
  */
 
 #include "defines.h"
-#include "includes.h"
 #include "structs.h"
-#include "declares.h"
 #include <stdio.h>
 
 /* ------------------------------------------------------------ */
@@ -20,7 +18,11 @@ int prefsOverrideRecipients;
 int prefsVerboseOutput;
 int prefsAddComment;
 int prefsExtraCRLFAtEnd;
+int prefsCacheDecrypted;
+int prefsCacheKeyrings;
+int addDashR;
 char prefsMyPager[MAX_COMMAND_LINE_LENGTH];
+char DecryptCacheName[MAX_COMMAND_LINE_LENGTH];
 
 #ifdef USE_DISPLAY_NAME
 	char mySecretKey[EMAIL_ADDRESS_MAX_LENGTH];
