@@ -1,4 +1,4 @@
-/* pgp4pine menus.c
+/* pgp4pine menus.c - Main UI stuff
  *
  * See common.c for the version and license.
  * Copyright (C) 1998 by Chris Wiegand
@@ -11,13 +11,13 @@
 #include "externs.h"
 
 /* ------------------------------------------------------------ */
-void fileVerifyDecryptMenu(const char *inFile,const char *outFile)
+void fileVerifyDecryptMenu(char *inFile,char *outFile)
 {
 	FILE *fin;
 	int  fertig=0,i=0;
-	char c,readline[CONSOLE_IO_LINE_LENGTH];
+	char readline[CONSOLE_IO_LINE_LENGTH];
+	int  c;  /* must be int, not char, to store EOF is char is 1 Byte. By Thorsten Wittmann. */
 	
-	// Try do decide what file we have (signed, encrypted)
 	if ((fin=fopen(inFile,"r"))==NULL)
 	{
 	  printf("Error opening Message !!\n");
@@ -26,58 +26,58 @@ void fileVerifyDecryptMenu(const char *inFile,const char *outFile)
 	else
 	do {
 	  fertig=0;
-	  while (((c=getc(fin))!=EOF) && !fertig)
+	  while (!fertig)
 	  {
-	    readline[i++]=c;
-	    if (c=='\n')
+	    if ((c=getc(fin))==EOF)
+	    {
+	      outFile=inFile; /* this usually is not 
+	      			 executed, EOF breaks directly */
+	      return;
+	    } 
+	    else if ((readline[i++]=c) == '\n')
 	    {
 	      readline[i]='\0';
 	      fertig=1;
-	    }
+	    } 
 	  }
 	  fertig=0;
 	  
-	  if (c==EOF)
+	  if (strncmp("-----BEGIN PGP SIGNED",readline,20)==0)
 	  {
-	    outFile=inFile; 
-	    return;
-	  }
-	  else if (strncmp("-----BEGIN PGP SIGNED",readline,20)==0)
-	  {
-	    // got signed message
+	    /* got signed message */
 	    fclose(fin);
 	    fileVerify(inFile,outFile);
-	    return;
+	    fertig=1;
 	  } 
 	  else if (strncmp("-----BEGIN PGP",readline,14)==0)
 	  {
-	    // got another PGP message
+	    /* got another type of PGP message (encrypted, keys ...) */
 	    fclose(fin);
 	    fileDecrypt(inFile,outFile);
 	    waitForReturn();
-	    return;
+	    fertig=1;
 	  }
 	  else
-	    i=0; // Got waste line, reset i
+	    i=0; /* Got waste line, reset i */
 	} while (!fertig);
 }
 void fileVerifyMenu(const char *inFile,const char *outFile)
 {
-	// inFile and outFile are a) just passed to fileVerifyDecrypt, and
-	// b) should already be copied into inFile, outFile in main.c:main()
-	// so they should be (safe) pointers...
+	/* inFile and outFile are a) just passed to fileVerifyDecrypt, and
+	   b) should already be copied into inFile, outFile in main.c:main()
+	   so they should be (safe) pointers... */
 	printf("\nVerify file\n\n");
-	fileVerify(inFile,outFile);
+	fileVerify(inFile,outFile); 	/* pki.c */
 	return;
 }
 
 void fileDecryptMenu(const char *inFile,const char *outFile)
 {
-	// inFile and outFile are a) just passed to fileVerifyDecrypt, and
-	// b) should already be copied into inFile, outFile in main.c:main()
-	// so they should be (safe) pointers...
+	/* inFile and outFile are a) just passed to fileVerifyDecrypt, and
+	   b) should already be copied into inFile, outFile in main.c:main()
+	   so they should be (safe) pointers... */
 	printf("\nDecrypt file\n\n");
-	fileDecrypt(inFile,outFile);
+	fileDecrypt(inFile,outFile);	/* pki.c */
 	waitForReturn();
 	return;
 }
@@ -120,7 +120,8 @@ void fileDecryptMenu(const char *inFile,const char *outFile)
  * pgp2 / gpg an alternative. This will make pgp4pine fail, pine presents a 
  * big broken warning (gnn..), and your back in the editor .. 
  */
-// ---------------------------------------------------------------------------------
+/*
+--------------------------------------------------------------------------------- */
 /* Menus for various combinations of signFile / encryptFile */
 int menu_noyes (int *sign, int *encrypt, int unknownkeys) /* Menu 1*/
 {
@@ -129,7 +130,7 @@ int menu_noyes (int *sign, int *encrypt, int unknownkeys) /* Menu 1*/
   documentStatus("Presenting menu for no sign/ask_or_yes encrypt ");  
   if (unknownkeys)
   {
-    documentStatus("with unknown keys, ");
+    documentStatus("with unknown keys\n");
     if (*encrypt==1)
       printf("Your recipient list has unknown keys, you can not encrypt. You may:\n");
     else
@@ -138,29 +139,29 @@ int menu_noyes (int *sign, int *encrypt, int unknownkeys) /* Menu 1*/
     if (myUserPrefs->pgpVersion == 5 || myUserPrefs->pgpVersion == 1)
     {
       printf("b) Ask the Keyserver for unknown keys and start over\n"
-             "c) Open a shell to add their key manually\nd) Abort and return to Pine\n\n");
-      switch (askAlphaRange("Make your choice:",'a','d'))
+             "c) Open a shell to add their key manually\nq) Abort and Quit\n\n");
+      switch (askAlphaRange("Make your choice ",'c','a','q'))
       {
       	  case 'a': action= 0; *sign = -1; *encrypt = -1; documentStatus("Selection: S-E-\n"); break;
     	  case 'b': action= 2;				documentStatus("Selection: Ask\n");  break;
 	  case 'c': action= 3;				documentStatus("Selectoin: Shell\n"); break;
-    	  case 'd': action=-1;				documentStatus("Selection: quit\n"); break;
+    	  default : action=-1;				documentStatus("Selection: quit\n");
       }
     }
     else
     {
-      	printf("b) Open a shell to add their key manually\nc) Abort and return to Pine\n\n");
-	switch (askAlphaRange("Make your choice:",'a','c'))
+      	printf("b) Open a shell to add their key manually\nq) Abort and Quit\n\n");
+	switch (askAlphaRange("Make your choice ",'b','a','q'))
 	{
 		case 'a': action= 0; *sign = -1; *encrypt = -1; documentStatus("Selection: S-E-\n"); break;
 		case 'b': action= 3;				documentStatus("Selection: Shell\n"); break;
-		case 'c': action=-1;				documentStatus("Selection: quit\n"); break;
+		default : action=-1;				documentStatus("Selection: quit\n");
 	}
     }
   }
   else
   {
-    documentStatus("with all-known keys, "); 
+    documentStatus("with all-known keys\n"); 
     if (*encrypt==1)
     {
       action = 1;
@@ -169,12 +170,12 @@ int menu_noyes (int *sign, int *encrypt, int unknownkeys) /* Menu 1*/
     else
     {
       printf("You know all recipient keys. You may:\n"
-             "a) Encrypt the message\nb) Send it unmodified\n\n");
-      switch (askAlphaRange("Make your choice:",'a','d'))
+             "a) Encrypt the message\nb) Send it unmodified\nq) Abort and Quit\n\n");
+      switch (askAlphaRange("Make your choice ",'b','a','q'))
       {
     	case 'a': action= 1; *sign = -1; *encrypt =  1; documentStatus("Selection: S-E+\n"); break;
     	case 'b': action= 0; *sign = -1; *encrypt = -1; documentStatus("Selection: S-E-\n"); break;
-      } 
+        default : action=-1;				documentStatus("Selection: quit\n");      } 
     } 
   }
   return action;
@@ -186,46 +187,47 @@ int menu_askask(int *sign, int *encrypt, int unknownkeys) /* Menu 2 */
   documentStatus("Presenting menu for ask sign/ask encrypt ");
   if (unknownkeys)
   {
-    documentStatus("with unknown keys, ");
+    documentStatus("with unknown keys\n");
     printf("Your recipient list has unknown keys. You may:\n"
            "a) Sign the message\nb) Send it unmodified\n");    
     if (myUserPrefs->pgpVersion == 5 || myUserPrefs->pgpVersion == 1)
     {
       printf("c) Ask the Keyserver for unknown keys and start over\n"
-             "d) Open a shell to add their key manually,\ne) Abort and return to Pine\n\n");
-      switch (askAlphaRange("Make your choice:",'a','e'))
+             "d) Open a shell to add their key manually,\nq) Abort and Quit\n\n");
+      switch (askAlphaRange("Make your choice ",'d','a','q'))
       {
     	case 'a': action= 1; *sign =  1; *encrypt = -1; documentStatus("Selection: S+E-\n"); break;
     	case 'b': action= 0; *sign = -1; *encrypt = -1; documentStatus("Selection: S-E-\n"); break;
     	case 'c': action= 2;				documentStatus("Selection: Ask\n");  break;
 	case 'd': action= 3;				documentStatus("Selection: Shell\n"); break;
-    	case 'e': action=-1;				documentStatus("Selection: quit\n"); break;
+    	default : action=-1;				documentStatus("Selection: quit\n");
       }
     }
     else
     {
-      printf("c) Open a shell to add their key manually,\nd) Abort and return to Pine\n\n"); 
-      switch (askAlphaRange("Make your choice:",'a','d'))
+      printf("c) Open a shell to add their key manually,\nq) Abort and Quit\n\n"); 
+      switch (askAlphaRange("Make your choice ",'c','a','q'))
       {
     	case 'a': action= 1; *sign =  1; *encrypt = -1; documentStatus("Selection: S+E-\n"); break;
     	case 'b': action= 0; *sign = -1; *encrypt = -1; documentStatus("Selection: S-E-\n"); break;
     	case 'c': action= 3;				documentStatus("Selection: Shell\n");  break;
-    	case 'd': action=-1;				documentStatus("Selection: quit\n"); break;
+    	default : action=-1;				documentStatus("Selection: quit\n"); 
       }
     }
   }
   else
   {
-    documentStatus("with all-known keys, "); 
+    documentStatus("with all-known keys\n"); 
     printf("You know all recipient keys. You may:\n"
            "a) Sign and encrypt the message\nb) Sign the message\n"
-           "c) Encrypt the message\nd) Send it unmodified\n\n");
-    switch (askAlphaRange("Make your choice:",'a','d'))
+           "c) Encrypt the message\nd) Send it unmodified\nq) Abort and Quit\n\n");
+    switch (askAlphaRange("Make your choice ",'d','a','q'))
     {
     	case 'a': action=1; *sign =  1; *encrypt =  1; documentStatus("Selection: S+E+\n"); break;
 	case 'b': action=1; *sign =  1; *encrypt = -1; documentStatus("Selection: S+E-\n"); break;
 	case 'c': action=1; *sign = -1; *encrypt =  1; documentStatus("Selection: S-E+\n"); break;
 	case 'd': action=0; *sign = -1; *encrypt = -1; documentStatus("Selection: S-E-\n"); break;
+	default : action=-1;			       documentStatus("Selection: quit\n");
     }
   }
   return action;
@@ -237,44 +239,45 @@ int menu_askyes(int *sign, int *encrypt, int unknownkeys)  /* Menu 3 */
   documentStatus("Presenting menu for ask sign/do encrypt ");
   if (unknownkeys)
   {
-    documentStatus("with unknown keys, ");
+    documentStatus("with unknown keys\n");
     printf("Your recipient list has unknown keys, you can not encrypt. You may:\n"
            "a) Only sign the message\nb) Send it unmodified\n");
     if (myUserPrefs->pgpVersion == 5 || myUserPrefs->pgpVersion == 1)
     {
       printf("c) Ask the Keyserver for unknown keys and start over\n"
-             "d) Open a shell to add their key manually,\ne) Abort and return to Pine\n\n");
-      switch (askAlphaRange("Make your choice:",'a','e'))
+             "d) Open a shell to add their key manually,\nq) Abort and Quit\n\n");
+      switch (askAlphaRange("Make your choice ",'d','a','q'))
       {
     	case 'a': action= 1; *sign =  1; *encrypt = -1; documentStatus("Selection: S+E-\n"); break;
 	case 'b': action= 0; *sign = -1; *encrypt = -1; documentStatus("Selection: S-E-\n"); break;
 	case 'c': action= 2;				documentStatus("Selection: Ask\n");  break;
 	case 'd': action= 3;				documentStatus("Selection: Shell\n"); break;
-	case 'e': action=-1;				documentStatus("Selection: quit\n"); break;
+	default : action=-1;				documentStatus("Selection: quit\n");
       }
     }
     else
     {
-      printf("c) Open a shell to add their key manually,\nd) Abort and return to Pine\n\n");
-      switch (askAlphaRange("Make your choice:",'a','d'))
+      printf("c) Open a shell to add their key manually,\nq) Abort and Quit\n\n");
+      switch (askAlphaRange("Make your choice ",'c','a','q'))
       {
     	case 'a': action= 1; *sign =  1; *encrypt = -1; documentStatus("Selection: S+E-\n"); break;
 	case 'b': action= 0; *sign = -1; *encrypt = -1; documentStatus("Selection: S-E-\n"); break;
 	case 'c': action= 3;				documentStatus("Selection: Shell\n");  break;
-	case 'd': action=-1;				documentStatus("Selection: quit\n"); break;
+	default : action=-1;				documentStatus("Selection: quit\n");
       }
     }
 
   }
   else
   {
-    documentStatus("with all-known keys, ");   
+    documentStatus("with all-known keys\n");   
     printf("You know all recipient keys. You may:\n"
-           "a) Sign and encrypt the message\nb) Encrypt the message\n\n");
-    switch (askAlphaRange("Make your choice:",'a','b'))
+           "a) Sign and encrypt the message\nb) Encrypt the message\nq) Abort and Quit\n\n");
+    switch (askAlphaRange("Make your choice ",'b','a','q'))
     {
     	case 'a': action=1; *sign =  1; *encrypt =  1; documentStatus("Selection: S+E+\n"); break;
 	case 'b': action=1; *sign = -1; *encrypt =  1; documentStatus("Selection: S-E+\n"); break;
+	default : action=-1;			       documentStatus("Selection: quit\n");
     }
   }
   return action;
@@ -286,41 +289,42 @@ int menu_yesask(int *sign, int *encrypt, int unknownkeys)  /* Menu 4 */
   documentStatus("Presenting menu for do sign/ask encrypt ");
   if (unknownkeys)
   {
-    documentStatus("with unknown keys, ");  
+    documentStatus("with unknown keys\n");  
     printf("Your recipient list has unknown keys. You may:\n"
            "a) Sign the message\n");
     if (myUserPrefs->pgpVersion == 5 || myUserPrefs->pgpVersion == 1)
     {
       printf("b) Ask the Keyserver for unknown keys and start over\n"
-             "c) Open a shell to add their key manually\nd) Abort and return to Pine\n\n");
-      switch (askAlphaRange("Make your choice:",'a','d'))
+             "c) Open a shell to add their key manually\nq) Abort and Quit\n\n");
+      switch (askAlphaRange("Make your choice ",'c','a','q'))
       {
     	case 'a': action= 1; *sign =  1; *encrypt = -1; documentStatus("Selection: S+E-\n"); break;
     	case 'b': action= 2;				documentStatus("Selection: Ask\n");  break;
     	case 'c': action= 3;				documentStatus("Selection: Shell\n"); break;
-	case 'd': action=-1;				documentStatus("Selection: quit\n"); break;
+	default : action=-1;				documentStatus("Selection: quit\n");
       }
     }
     else
     {
-      printf("b) Open a shell to add their key manually\nc) Abort and return to Pine\n\n");
-      switch (askAlphaRange("Make your choice:",'a','c'))
+      printf("b) Open a shell to add their key manually\nq) Abort and Quit\n\n");
+      switch (askAlphaRange("Make your choice ",'b','a','q'))
       {
     	case 'a': action= 1; *sign =  1; *encrypt = -1; documentStatus("Selection: S+E-\n"); break;
     	case 'b': action= 3;				documentStatus("Selection: Shell\n");  break;
-    	case 'c': action=-1;				documentStatus("Selection: quit\n"); break;
+    	default : action=-1;				documentStatus("Selection: quit\n");
       }
     }       
   }
   else
   {
-    documentStatus("with all-known keys, ");   
+    documentStatus("with all-known keys\n");   
     printf("You know all recipient keys. You may:\n"
-           "a) Sign and encrypt the message\nb) Sign the message\n\n");
-    switch (askAlphaRange("Make your choice:",'a','b'))
+           "a) Sign and encrypt the message\nb) Sign the message\nq) Abort and Quit\n\n");
+    switch (askAlphaRange("Make your choice ",'b','a','q'))
     {
     	case 'a': action=1; *sign =  1; *encrypt =  1; documentStatus("Selection: S+E+\n"); break;
-	case 'b': action=1; *sign = -1; *encrypt =  1; documentStatus("Selection: S-E+\n"); break;
+	case 'b': action=1; *sign =  1; *encrypt = -1; documentStatus("Selection: S+E-\n"); break;
+    	default : action=-1;			       documentStatus("Selection: quit\n");
     }    
   }
   return action;
@@ -332,77 +336,82 @@ int menu_yesyes(int *sign, int *encrypt, int unknownkeys)  /* Menu 5 */
   documentStatus("Presenting menu for do sign/do encrypt ");
   if (unknownkeys)
   {
-    documentStatus("with unknown keys, ");  
+    documentStatus("with unknown keys\n");  
     printf("Your recipient list has unknown keys, you can not encrypt. You may:\n"
            "a) Only sign the message\n");
     if (myUserPrefs->pgpVersion == 5 || myUserPrefs->pgpVersion == 1)
     {
       printf("b) Ask the Keyserver for unknown keys and start over\n"
-             "c) Open a shell to add their key manually\nd) Abort and return to Pine\n\n");
-      switch (askAlphaRange("Make your choice:",'a','d'))
+             "c) Open a shell to add their key manually\nq) Abort and Quit\n\n");
+      switch (askAlphaRange("Make your choice ",'c','a','q'))
       {
     	case 'a': action= 1; *sign =  1; *encrypt = -1; documentStatus("Selection: S+E-\n"); break;
     	case 'b': action= 2;				documentStatus("Selection: Ask\n");  break;
 	case 'c': action= 3;				documentStatus("Selection: Shell\n");  break;
-    	case 'd': action=-1;				documentStatus("Selection: quit\n"); break;   
+    	default : action=-1;				documentStatus("Selection: quit\n");    
       }
     }
     else
     {    
-      printf("b) Open a shell to add their key manually\nc) Abort and return to Pine\n\n");
-      switch (askAlphaRange("Make your choice:",'a','c'))
+      printf("b) Open a shell to add their key manually\nq) Abort and Quit\n\n");
+      switch (askAlphaRange("Make your choice ",'b','a','q'))
       {
     	case 'a': action= 1; *sign =  1; *encrypt = -1; documentStatus("Selection: S+E-\n"); break;
     	case 'b': action= 3;				documentStatus("Selection: Shell\n");  break;
-    	case 'c': action=-1;				documentStatus("Selection: quit\n"); break;   
+    	default : action=-1;				documentStatus("Selection: quit\n");   
       }
     }
   }
   else
   {
-    documentStatus("with all-known keys: No menu\n");   
-    action=1;
+    documentStatus("with all-known keys\n");
+    printf("All keys are known. You may\na) Sign and encrypt the message\nq) Abort and Quit\n\n");
+    if (askAlphaRange("Make your choice ",'a','a','q')=='a')
+      { action=1; documentStatus("accepted\n");}
+    else
+      { action=-1;documentStatus("quit\n");}
   }
   return action;
 }
-// --------------------------------------------------------------------------------- 
-
+/* ---------------------------------------------------------------------------------  */
 int fileSignEncryptMenu(const char *inFile, char *outFile, char *recipients)
 {
-   // all of the pointer arguments above should be "safe" pointers, 
-   // as they are given variables in main.c:main()
+   /* all of the pointer arguments above should be "safe" pointers, 
+      as they are given variables in main.c:main() */
 	
    int signFile,encryptFile,encryptToSelf=0,useASCIIArmor,useUniversalText,useDetachedSigs;
    char tmpList[EMAIL_ADDRESS_MAX_LENGTH];
    char keyrecipients[EMAIL_ADDRESS_MAX_LENGTH];
    char nokeyrecipients[EMAIL_ADDRESS_MAX_LENGTH];
 
-   int  action=10; /* 10 is unused */
-   int (*menu)(int *,int *,int);
+   int  ret,action=10; /* 10 is unused */
+   int (*menu)(int *,int *,int);	/* pointer to menu function */
 
    signFile = myUserPrefs->autoSign;
    encryptFile = myUserPrefs->autoEncrypt;
 
-   printf("Your preset is: ");
-   switch (signFile*3 + encryptFile)
-   {
-     case -4: printf("do nothing\n");		break;   // S-E-
-     case -3: printf("don't sign\n");		break;   // S-E?
-     case -2: printf("encrypt and no sign\n");	break;   // S-E+
-     case -1: printf("don't encrypt\n");	break;   // S?E-
-     case  0: printf("none\n");			break;   // S?E?
-     case  1: printf("try to encrypt\n");	break;   // S?E+
-     case  2: printf("sign and never encrypt\n"); break; // S+E-
-     case  3: printf("always sign\n");		break;   // S+E?
-     case  4: printf("sign + encrypt\n");	break;   // S+E+
+   if (signFile || encryptFile) {
+     printf("Your preset is: ");
+     switch (signFile*3 + encryptFile)	/* Ask two variables in one switch.. */
+     {
+       case -4: printf("do nothing\n");		break;   /* S-E- */
+       case -3: printf("don't sign\n"); 	  break;   /* S-E? */
+       case -2: printf("encrypt and no sign\n");  break;   /* S-E+ */
+       case -1: printf("don't encrypt\n");	  break;   /* S?E- */
+       case  0: printf("none\n");		  break;   /* S?E? */
+       case  1: printf("try to encrypt\n");	  break;   /* S?E+ */
+       case  2: printf("sign and never encrypt\n"); break; /* S+E- */
+       case  3: printf("always sign\n");	  break;   /* S+E? */
+       case  4: printf("sign + encrypt\n");	  break;   /* S+E+ */
+     }
    }
 
    do {	
-        if ((signFile == -1) && (encryptFile == -1)) // Do nothing at all
+        if ((signFile == -1) && (encryptFile == -1)) /* Do nothing at all */
    	/* Return 0 as a sign to send unmodified (message is still in infile, not tmpfile) */
 	  return 0;
 
-	// initialize recipients lists
+	/* initialize recipients lists */
 
 	if (strlen(recipients) < 3 || prefsOverrideRecipients == 1) 
 	{
@@ -410,8 +419,8 @@ int fileSignEncryptMenu(const char *inFile, char *outFile, char *recipients)
 		printf("Please enter the recipients below. Type . by itself on it's own line to end.\n");
 		do {
 			scanf("%s",tmpList);
-			// Using fgets seems to break the strcmp() below...
-//			fgets(tmpList, EMAIL_ADDRESS_MAX_LENGTH, stdin);
+			/* Using fgets seems to break the strcmp() below... */
+		     /* fgets(tmpList, EMAIL_ADDRESS_MAX_LENGTH, stdin); */
 			strcat(recipients,tmpList);
 			strcat(recipients," ");
 		} while (strcmp(tmpList,"."));
@@ -473,15 +482,23 @@ int fileSignEncryptMenu(const char *inFile, char *outFile, char *recipients)
 
 		if (encryptFile > 0) 
 		{
-			myUserPrefs->detachedSig = -1; // can't detach signature when encrypting...
+			myUserPrefs->detachedSig = -1; /* can't detach signature when encrypting... */
 			encryptToSelf = myUserPrefs->encryptToSelf;
 			if (encryptToSelf == 0) encryptToSelf = askInteger("Do you want to encrypt to yourself, too? ",1);
 		}
 		useDetachedSigs = myUserPrefs->detachedSig;
 		if (useDetachedSigs == 0) useDetachedSigs = askInteger("Do you want to use a detached signature?",-1);
 
-		fileSignEncrypt(inFile,outFile,signFile,encryptFile,keyrecipients,useASCIIArmor,useUniversalText,encryptToSelf,useDetachedSigs);
-//		waitForReturn();
+		ret=fileSignEncrypt(inFile,outFile,signFile,encryptFile,keyrecipients,useASCIIArmor,useUniversalText,encryptToSelf,useDetachedSigs);
+		if (ret<0)
+		{
+		  fprintf(stderr,"Error while encrypting ! Aborting now.\n");
+		  return -1;
+		} else if (ret==1) {	/* fileSignEncrypt returned 'send unmodified' (failed to clearsign) */
+		  return 0;
+		} else if (ret==2) {	/* fileSignEncrypt returned 'return to Pine' (abort, but without error msg.) */
+		  return -1;
+		}
 		break;
 	  case 2: /* Ask server */
 		fileAskKey(nokeyrecipients);
@@ -493,10 +510,10 @@ int fileSignEncryptMenu(const char *inFile, char *outFile, char *recipients)
 		regetPublicKeyring();
 		break;
 	  case 0:  /* send unmodofied */
-//	  	return 0;
+/*	  	return 0; */
 		break;
 	  case -1: /* Abort message */
-//	  	return -1;
+/*	  	return -1; */
 		break;
 	  default: printf("Error: action=%d, menu selection went wrong !!\n",action);
 	}
